# Debugging level, 0=errors only, 1=return status of smtp server,
#   2=smtp server communication, 3=detailed smtp server communication,
#   4=smtp client communication, tracebacks
DEBUG_LEVEL=3

# Logfile
LOGFILE='/var/log/sagator.log'

# Where is new root path. For example '/var/spool/vscan'
CHROOT='/var/spool/vscan'

# User and group, under which this program runs.
USER='vscan'
GROUP='vscan'

# SMTP server host and port. You must define this smtp server
# in postfix without filtering.
SMTP_HOST='127.0.0.1'
SMTP_PORT=26

# host and port to listen
BIND_HOST='localhost'
BIND_PORT=10027

# Quarantine dir, in which are stored viruses and spams.
QUARANTINE_DIR='/tmp/quarantine'

# Scanners
from base import *
from mimeparse import mimeparse,mime_ext
from clamav import clamscan,clamd
from nodold import nodold
from spamassassin import spamassassin,spamassassind
from decompress import decompress
from patterns import *

# Define scanners
SPAMSTRING='^X-Spam-Level: \*\*\*\*\*'
SA_MAX_FILE=500000
SCANNERS=[
  # ClamAV
  match_first(
    clamd(['localhost',3310]),
    clamd('/var/spool/vscan/clamd'),
    #mimeparse(clamd(['localhost',3310])),
    clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','-r','--mbox'])
    #,mimeparse(stream2file(clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','-r'])))
  ),
  # Simple scanners
  #string_scan(VIR_PATTERNS),
  #regexp_scan({'virname':['___PATTERN___']}),
  #mime_ext(mime_ext.EXECUTABLES),
  mimeparse(stream2file(decompress(
    clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','--disable-archive','-r'])))),
  # OpenAntivirus DB support, highly experimental, don't use
  #oadb('/usr/share/clamav/viruses.db','/usr/share/clamav/viruses.db2'),
  # NODOLD
  #mimeparse(stream2file(nodold(['localhost',8448]))),
  # SpamAssassin
  match_first(
    spamassassind(['localhost',783],SPAMSTRING,SA_MAX_FILE),
    spamassassin(['/usr/bin/spamassassin','-e'],SPAMSTRING,SA_MAX_FILE)
  ),
  # Return no virus
  l_return()
]
TEMPFAIL_ON_SCANNER_FAIL=1

# Drop emails, which contains viruses or spams.
# Define a regular expression pattern. If this pattern is found
# in reply of scanner, then mail is dropped elsewhere, it is rejected.
DROP='(SPAM|sobig|frethem|lirva|klez|palyh|bugbear)'

# Always send, and do not reject or drop.
# Define a regular expression pattern. If this pattern is found in virname
# mail is sent to recipients always. If it is not set, only clean 
# mails are sent, others are rejected or dropped.
ALWAYS_SEND='eicar'

# If this regular expression is found in virname, mail is not
# quarantined. If this config parameter is not set, all virsuses
# are quarantined.
DONT_QUARANTINE='eicar'

# Send virus reports as ...
REPORT_SENDER='viralert@salstar.sk'
# Send virus reports to ['...','...']
REPORT_RECIPIENTS=['vir@salstar.sk']

# MESSAGE REPORT TEMPLATE
REPORT_MSG='''From: %s
To: %s
Subject: ALERT, %s FOUND!

                             VIRUS FOUND!

---------------------------------------------------------------------
SMTP COMMUNICATION:
%s\
---------------------------------------------------------------------
STATUS: %s
QUARANTINED AS: %s
---------------------------------------------------------------------
OUTPUT OF SCANNER:
%s\
---------------------------------------------------------------------
HEADER OF MESSAGE:
%s\
'''
